function bound3=choseBound(vertex,bound,source,nPoints_)
% bound3=choseBound(vertex,bound,source,nPoints_)
% input: 
% vertex - the set of vertices in the camera coordinate system
% bound - the full set of boundary vertices indices
% source - the index of the source vertex
% nPoints_ (optional) - the number of vertices we want at the
%                       boundary, the default is 80
% output:
% bound: the set of point over the partial view boundary, which are
% equally spaced by angles of pi/40, measured from the central point
% Copyright (c) 2015, Susana Brandao
    
 nPoints=80;
  if nargin>4
      nPoints=nPoints_;
  end
  
  bound(end)=[];
  
 
  vertex=vertex(:,1:2);
  
  
  source=vertex(source,:);
  vertexI=vertex(bound,:);
 
  vertexI=[vertexI(:,1),vertexI(:,2)];
  source=[source(:,1),source(:,2)];  
  c=convhull(vertexI(:,1),vertexI(:,2));
  
  %center objects around the source
  vertexI=vertexI-repmat(source,size(vertexI,1),1);
  theta=atan2(vertexI(:,2),vertexI(:,1));
  %start with the point in the north  
  [minP,ind]=min(abs(theta-pi/2));
  vertexI=circshift(vertexI,-ind+1);
  bound2=circshift(bound(:),-ind+1);
  
  theta=atan2(vertexI(:,2),vertexI(:,1));
  r=sqrt(sum(vertexI.*vertexI,2));
  theta(theta<0)=theta(theta<0)+2*pi;
  d=theta;
  
    
  bI=zeros(nPoints,1);

  
  for i=1:nPoints
      ind=find(abs(d-(i-1)*2*pi/(nPoints-1))<pi/(nPoints-1));

      
      if ~isempty(ind)          
          [minS,n]=max(r(ind));  % get the thing with the lowest radius in the interval
          bI(i)=ind(n);
          
      else
          [minS,n]=min(abs(d-(i-1)*2*pi/(nPoints-1))); 
          bI(i)=n;
          
      end
   
  end  
  bound3=bound2(bI);
 
  
end

function cR=mexT(c,m)
n1=length(c);
n2=length(m);
nt=n1*n2;
cR=cell(nt,1);
for i=1:n1
    for k=1:n2
        cR{(i-1)*n2+k}=[m{k},c{i}];
    end
end
end
