function [source,un,l,sT,hK]=computeTempAtSurfaceFixedTime(mesh,coord,k,point)  
  % [source,un,l,sT,hK]=computeTempAtSurfaceFixedTime(mesh,coord,k,point)
  %compute laplace, and solves the heat equation for t=1/lambda2
  %%input:
  %mesh: the vertex indices of a triangular mesh
  %coord: the vertex coordinates
  %im: a scalar corresponding to a color
  %k: the boundary indices (closed cycle, i.e., first==last)
  %point: the source index
  %
  %output
  % source is the temperature at the vertices in k, assuming source at
  %            point
  % un is the projection of the eigenvectors at k in the eigenvectors at
  %            the point  (no idea why I needed this)
  % l are the eigenvalues
  % st, is the temperature at the point
  % hK, is the temperature on the whole surface 
  % Copyright (c) 2015, Susana Brandao
  
  L0=computeLap(coord,mesh);   
  [V,D] = eigs(L0,30,0.001); % warning : it takes lot of time and depends on the initialization
        
  [s,ind]=sort(diag(D));  
  V=V(:,ind);
  s(1)=0;   
  D=diag(s);    
  V = real(V);      
 
  g=sum(s<0.001);
  t=1./(s(g+1));
  scale=-kron(diag(D)',t');
  scale=exp(scale);

  
  hK=((V.*repmat(V(point,:),size(V,1),1))*scale')*(size(L0,1));
  
  source=hK(k,:);
  un=V(k,:).*repmat(V(point,:),size(k,1),1);
  l=diag(D);
  sT=hK(point,:);   
  
end