function [source,un,l,sT,hK]=computeTempAtSurface_color(mesh,coord,im,k,point)
%[source,un,l,sT,hK]=computeTempAtSurface_color(mesh,coord,im,k,point)
%compute laplace, and solves the in-homogeneous heat equation for t=1/lambda2
%input:
%mesh: the vertex indices of a triangular mesh 
%coord: the vertex coordinates
%im: a scalar corresponding to a color
%k: the boundary indices (closed cycle, i.e., first==last)
%point: the source index
%output:
%source: temperature at the boundary
%un: (for debuging: the product between the value of eigenvectors at the boundary and the eigenvectors at the source)
%l: the eigenvalues
%sT: the temperature at the source
%hK: the temperature over the surface
% Copyright (c) 2015, Susana Brandao

  %compute laplace,
    L0=computeLap(coord,mesh);
%     c=rgb2hsv(im/255);
    c=im(:,1);
%     y=find(c==0);
%     c(y)=0.00001;
    c=c/2+0.5;
    
    c=sparse(1:length(L0),1:length(L0),double(c));
    [V,D] = eigs(L0,c,30,0.001); % warning : it takes lot of time and depends on the initialization  
    
    %    
%          
    [s,ind]=sort(diag(D));
    V=V(:,ind);
    s(1)=0;
    D=diag(s);   
    V = real(V)*sqrt(size(V,1));          
    
 
    g=sum(s<0.001);
    t=1./(s(g+1));  
    scale=-kron(s',t);
    scale=exp(scale);    
    
    hK=(V.*repmat(V(point,:).*c(point,point),size(V,1),1))*scale';
  
    source=hK(k,:);
    un=V(k,:).*repmat(V(point,:),size(k,1),1);
    l=s;
    sT=hK(point,:);
  
end