function [vertex,mesh,rgbMesh,indDepth,indRGB]=getPersonMesh(depth,rgb, background,kinect,R,t)
%  [vertex,mesh,rgbMesh,indDepth]=getPersonMesh(depth,rgb,background,kinect)
%  this function returns the segmented partial view and the
%  corresponding RGB. The vertices are defined on the room
%  coordinate system.
%  input:
%  depth: depth image from a kinect
%  rgb:  image from a kinect
%  background: background depth image
%  kinect: kinect structure with the camera matrices and registration (see v_kinect.mat)
%  R,t: the transformation that aligns the point cloud with the vertical
%  direction, i.e., so that, given a set of vertices in the camera coordinate system, they become 
%                      aligned with the vertical by
%                      (vertex-repmat(t,size(vertex,1),1))*R'
%  output:
%  vertex: Nx3 list with the coordinates of each point
%  mesh: Mx3 list with the triangles: line j in the list will be:
%                                      [t1,t2,t3], where ti are
%                                      indices in list vertex
%  rgbMesh: Nx3 rgb colors for each of the vertices in the vertex list
%  indDepth: the index in the depth image of each vertex
%  indRGB: the index in the rgb image of each vertex
%  Copyright(r) 2015 Susana Brandao

  wIm=size(depth,2);
  hIm=size(depth,1);

   
  mask=(abs(depth-background)>4);
  mask(depth==2047)=false;
  CC = bwconncomp(mask);
  S = regionprops(CC,'Area');
  
  [mA,ii]=max([S.Area]);
  mask=false(hIm,wIm);
  mask(CC.PixelIdxList{ii}) = true;
  mask=imfill(mask,4,'holes');
  
  [vertex,lines,col,mesh]=transform(depth,kinect);
  [rgbMesh,indRGB]=rgbFromVertex(vertex,rgb,kinect);
  vertex=makeVertical(vertex,R,t);
  mm=vertex(:,3)>0.6;
  col=col(mm);
  lines=lines(mm);
  vertex=vertex(mm,:);
  rgbMesh=rgbMesh(mm,:);
  indRGB=indRGB(mm);

  f=zeros(max(max(mesh)),1);
  f(mm)=1:sum(mm);
  mmI=f(mesh);
  mesh=mmI(sum(mmI==0,2)==0,:);
  
    
  indDepth=(col-1)*hIm+lines;        %vertices -> image pixeis  
  a=zeros(hIm*wIm,1);                %blob image Pixeis -> vertices   
  b=1:length(indDepth);              %vertices\vertices with negative z
  a(indDepth)=b;                     %mapa dos pixeis para a lista em vertex (inverso do indDepth)
  a(~mask)=0;                        %indices na lista vertex que pertencen a blob
  
  d=zeros(size(vertex,1),1);         
  c=a(a>0);                          %indices na lista vertex: blob=vertex(c,:)
  d(c)=1:length(c);                  %mapa dos indices da lista vertex para indices na lista da blob
        
  meshB=d(mesh);                     %usar o mapa para refazer a mesh  : todos os que nao estao na blob ficam a zero
  mm=sum(meshB==0,2)==0;             % remover triangulos que ficaram incompletos
  meshB=meshB(mm,:);                 % esta seria a mesh final nao fora o facto de poderem ter desaparecido vertices por estarem em triangulos incompletos
  newV=unique(meshB);                %indices na lista da blob correspondentes a vertices em triangulos - se nao tivessem desaparecido, isto seria a identidade
  e=zeros(max(newV),1);              %mapa da lista da blob 
  e(newV)=1:length(newV);            %       para a lista de vertices em triangulos
  
  meshB=e(meshB);                    %%refazer a mesh so com os triangulos
  mm=sum(meshB==0,2)==0;
  mesh=meshB(mm,:);                  % mesh refeita de triangulos - agora nao se perdem vertices
  
                
  
  vertex=vertex(c,:);                % vertices da blob
  vertex=vertex(newV,:);             % vertices da blob menos os vertices que estavam em triangulos incopletos.
  rgbMesh=rgbMesh(c,:);                % vertices da blob
  rgbMesh=rgbMesh(newV,:);             % vertices da blob menos os vertices que estavam em triangulos incopletos.
  indRGB=indRGB(c);                % vertices da blob
  indRGB=indRGB(newV);             % vertices da blob menos os vertices que estavam em triangulos incopletos.
  indDepth=indDepth(c,:);
  indDepth=indDepth(newV,:);

end