function [rgbT,ind]=rgbFromVertex(xy,rgb,kinect)
% [rgbT,ind]=rgbFromVertex(xy,rgb,kinect)
%gets the color in rgb corresponding to a set of 3d points in xy using the
%kinect parameters -- this function was originally created by
%Helder Miranda
% input:
% xy - Nx3 vertices coordinates in the depth camera coordinate system
% rgb - the rbg image provided by the kinect
% kinect - a structure containing: (i) the rotation R and translation T from the
% depth to the RGB camera. 
%     kinect.R
%     kinect.T
%     Transformation: assuming xy in the depth camare system and
%     xyRGB in the rgb camera coordinate system, the two are
%     related by: xyRGB= R*xy' +repmat(T(:),1,N)
%                                 (ii) the intrinsics of the RGB camera
% in the kinect, 
%     kinect.krgb
%     projection of the vertices in the image coordinates uvRGB
%     uvRGB=krgb*([xyRGB(1,:)./xyRGB(3,:);
%     xyRGB(2,:)./xyRGB(3,:)],ones);
% Copyright(r) 2015 Susana Brandao
xd(3,:)=ones(1, size(xd,2));

xp=krgb*xd;      




R=double(kinect.R);
T=double(kinect.T);
krgb=double(kinect.krgb);
kc_rgb=double(kinect.kc_rgb);

p3=R*(xy');
p3d(1,:)=p3(1,:)+T(1);
p3d(2,:)=p3(2,:)+T(2);
p3d(3,:)=p3(3,:)+T(3);
 
xn=[p3d(1,:)./p3d(3,:); p3d(2,:)./p3d(3,:)];
     
xd(1:2,:)=xn;
xd(3,:)=ones(1, size(xd,2));

xp=krgb*xd;

xp(2,(find(xp(2,:)>=480-4)))=480-4;
 xp(1,(find(xp(1,:)>=640-4)))=640-4;
 xp(2,(find(xp(2,:)<=0)))=1;
 xp(1,(find(xp(1,:)<=0)))=1;
 

ind=sub2ind([480 640],round(xp(2,:))+4,round(xp(1,:)+4)); % this gives the indices in rgb that correspond to the verices

rgb2=reshape(rgb,480*640,3);

rgbT=rgb2(ind,:);

end
