function [matriz,lines,col,mesh]=transform(depth,kinect)
%[matriz lines, col, mesh]=transform(im,kinectStructure)
%input:
%im: depth image
%kinectStructure: the kinect structure with alfa, beta1 and kir, so
%that coordinates in the depth camera coordinate system are
%computed as: 
%   z=(1./(double(v).*alfa+beta1));
%   x=(col(:)-1-kir(1,3)).*z/kir(1,1);
%   y=(lines(:)-1-kir(2,3)).*z/kir(2,2);   
%output:
%matriz: Nx3 double matrix with the xyz coordinates
%lines: line of each vertex in matriz
%col: column of each vertex in matrix
%mesh: Mx3 int matrix with the triangle indices
% Copyright(r) 2015 Susana Brandao 

alfa=double(kinect.alfa);
beta1=double(kinect.beta1);
kir=kinect.kir;



numLines=size(depth,1);
numCol=size(depth,2);
mesh=createKinNeighMesh(numLines,numCol);

mask3=depth==2047;
col=ones(size(depth,1),1)*(1:size(depth,2));%alterado por causa do C
lines=(1:size(depth,1))'*ones(1,size(depth,2));%alterado por causa do C
%depth=double(depth);
%depth(mask3)=nan;
%depth=inpaint_nans(depth,0);

col=col(~mask3);
lines=lines(~mask3);
ind=lines+(col-1)*numLines;
ind=ind(:);

a=zeros(max(max(mesh)),1);
a(ind)=1:length(ind);

mesh=a(mesh);                    %altera os indices e 
mesh=mesh(~sum(mesh==0,2)>0,:);   %mantem so os que tem a vizinhanca completa


v=depth(~mask3);
%clov=depth(:);

z=(1./(double(v).*alfa+beta1));

x=(col(:)-1-kir(1,3)).*z/kir(1,1);

y=(lines(:)-1-kir(2,3)).*z/kir(2,2);
matriz=[x y z];





end
